==> cr12g-panhuo-impl-3.0.0-20210510.094139-7-sources.jar: com/ejianc/business/asset/bean/TurnoverRecordEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 周转记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_turnover_record")
public class TurnoverRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 物资分类编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资code
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_type")
    private Integer assetType; // 台车、周转材
    @TableField(value="asset_code")
    private String assetCode; // 编码
    @TableField(value="use_asset_code")
    private String useAssetCode; // 利旧资产编码
    @TableField(value="use_asset_id")
    private Long useAssetId; // 利旧资产id
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="source_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date sourceDate; // 业务日期
    @TableField(value="add_ton")
    private java.math.BigDecimal addTon; // 加工吨位
    @TableField(value="use_ton")
    private java.math.BigDecimal useTon; // 利旧吨位
    @TableField(value="ton")
    private java.math.BigDecimal ton; // 吨位
    @TableField(value="source_id")
    private Long sourceId; // 来源单据id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源单据子表id
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    @TableField(value="asset_belong_type")
    private Integer assetBelongType; // 资产归属类型
    @TableField(value="belong_org_id")
    private Long belongOrgId; // 资产归属公司id
    @TableField(value="belong_org_name")
    private String belongOrgName; // 资产归属公司名称
    @TableField(value="source_type")
    private String sourceType; // 来源单据标识
    @TableField(value="source_type_name")
    private String sourceTypeName;// 来源单据标识




    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }
    
    

    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 台车、周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 台车、周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 利旧资产编码
     */
    public String getUseAssetCode() {
        return useAssetCode;
    }

    /**
     * 利旧资产编码
     */
    public void setUseAssetCode(String useAssetCode) {
        this.useAssetCode = useAssetCode;
    }
    /**
     * 利旧资产id
     */
    public Long getUseAssetId() {
        return useAssetId;
    }

    /**
     * 利旧资产id
     */
    public void setUseAssetId(Long useAssetId) {
        this.useAssetId = useAssetId;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 业务日期
     */
    public java.util.Date getSourceDate() {
        return sourceDate;
    }

    /**
     * 业务日期
     */
    public void setSourceDate(java.util.Date sourceDate) {
        this.sourceDate = sourceDate;
    }
    /**
     * 加工吨位
     */
    public java.math.BigDecimal getAddTon() {
        return addTon;
    }

    /**
     * 加工吨位
     */
    public void setAddTon(java.math.BigDecimal addTon) {
        this.addTon = addTon;
    }
    /**
     * 利旧吨位
     */
    public java.math.BigDecimal getUseTon() {
        return useTon;
    }

    /**
     * 利旧吨位
     */
    public void setUseTon(java.math.BigDecimal useTon) {
        this.useTon = useTon;
    }
    /**
     * 吨位
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 吨位
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 来源单据id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源单据子表id
     */
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 来源单据子表id
     */
    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属公司id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属公司id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属公司名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属公司名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    /**
     * 来源单据标识
     */
    public String getSourceType() {
        return sourceType;
    }

    /**
     * 来源单据标识
     */
    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    
}

==> cr12g-panhuo-impl-3.0.0-20210522.081614-65-sources.jar: com/ejianc/business/asset/bean/TurnoverRecordEntity.java <==
package com.ejianc.business.asset.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.business.asset.consts.TurnoverTypeEnum;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 周转记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_turnover_record")
public class TurnoverRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 物资分类编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资code
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_type")
    private Integer assetType; // 台车、周转材
    @TableField(value="asset_code")
    private String assetCode; // 编码
    @TableField(value="use_asset_code")
    private String useAssetCode; // 利旧资产编码
    @TableField(value="use_asset_id")
    private Long useAssetId; // 利旧资产id
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="source_date")
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date sourceDate; // 业务日期
    @TableField(value="add_ton")
    private java.math.BigDecimal addTon; // 加工吨位
    @TableField(value="use_ton")
    private java.math.BigDecimal useTon; // 利旧吨位
    @TableField(value="ton")
    private java.math.BigDecimal ton; // 吨位
    @TableField(value="source_id")
    private Long sourceId; // 来源单据id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源单据子表id
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    @TableField(value="asset_belong_type")
    private Integer assetBelongType; // 资产归属类型
    @TableField(value="belong_org_id")
    private Long belongOrgId; // 资产归属公司id
    @TableField(value="belong_org_name")
    private String belongOrgName; // 资产归属公司名称
    @TableField(value="source_type")
    private String sourceType; // 来源单据标识
    @TableField(value="source_type_name")
    private String sourceTypeName;// 来源单据标识
    @TableField(value="spec")
    private String spec; // 规则/型号
    @TableField(value="unit")
    private String unit; // 计量单位



    public static TurnoverRecordEntity instance(TurnoverTypeEnum turnoverTypeEnum) {
        return new TurnoverRecordEntity(turnoverTypeEnum.getCode(), turnoverTypeEnum.getName());
    }

    private TurnoverRecordEntity() {
    }

    public TurnoverRecordEntity(String sourceType, String sourceTypeName) {
        this.sourceType = sourceType;
        this.sourceTypeName = sourceTypeName;
    }

    public String getSourceTypeName() {
        return sourceTypeName;
    }

    public void setSourceTypeName(String sourceTypeName) {
        this.sourceTypeName = sourceTypeName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 台车、周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 台车、周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 利旧资产编码
     */
    public String getUseAssetCode() {
        return useAssetCode;
    }

    /**
     * 利旧资产编码
     */
    public void setUseAssetCode(String useAssetCode) {
        this.useAssetCode = useAssetCode;
    }
    /**
     * 利旧资产id
     */
    public Long getUseAssetId() {
        return useAssetId;
    }

    /**
     * 利旧资产id
     */
    public void setUseAssetId(Long useAssetId) {
        this.useAssetId = useAssetId;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 业务日期
     */
    public java.util.Date getSourceDate() {
        return sourceDate;
    }

    /**
     * 业务日期
     */
    public void setSourceDate(java.util.Date sourceDate) {
        this.sourceDate = sourceDate;
    }
    /**
     * 加工吨位
     */
    public java.math.BigDecimal getAddTon() {
        return addTon;
    }

    /**
     * 加工吨位
     */
    public void setAddTon(java.math.BigDecimal addTon) {
        this.addTon = addTon;
    }
    /**
     * 利旧吨位
     */
    public java.math.BigDecimal getUseTon() {
        return useTon;
    }

    /**
     * 利旧吨位
     */
    public void setUseTon(java.math.BigDecimal useTon) {
        this.useTon = useTon;
    }
    /**
     * 吨位
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 吨位
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 来源单据id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源单据子表id
     */
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 来源单据子表id
     */
    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属公司id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属公司id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属公司名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属公司名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    /**
     * 来源单据标识
     */
    public String getSourceType() {
        return sourceType;
    }

    /**
     * 来源单据标识
     */
    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    
}
